@@ -306,13 +306,10 @@ INSERT INTO "celini" VALUES(6,'северна-и-южна-корея-в-спор
 INSERT INTO "celini" VALUES(7,'меню-незадължително',0,0,0,5,5,0,'заглавѥ','text',1527027334,0,'меню незадължително','','','','<ul>
 <li>Първо</li><li>Второ</li>
 <li>Трето
-  <ul>
-    <li>Първо</li>
-    <li>Второ</li>
-  </ul>
+  <ul><li>Първо</li><li>Второ</li></ul>
 </li>
 <li>Четвърто</li>
-<ul>','лѣво','bg-bg','-rwxr-xr-x',0,0,0,0,0,0,5);
+</ul>','лѣво','bg-bg','-rwxr-xr-x',0,0,0,0,0,0,5);
 
 INSERT INTO "celini" VALUES(8,'реклама',0,0,0,5,5,0,'заглавѥ','text',1527027663,0,'Реклама','','','','<div style="height:12em;background:red"> text here</div>
 <div style="height:12em;background:blue">image and text</div>','дѣсно','bg-bg','-rwxr-xr-x',0,0,0,0,3,1558563642,5);
@@ -377,3 +374,54 @@ DELETE FROM stranici WHERE id in (5,6,7,8);
 -- NO "DROP COLUMN" in SQLite so we will not do the usual workaround with
 -- recreating the table.table
 
+-- 201806252200 up
+UPDATE stranici set published=2 WHERE alias='ѿносно';
+-- Synchronise 'published' status of content with their pages
+UPDATE celini SET published=2 where page_id=(SELECT id FROM stranici WHERE alias='ѿносно');
+-- update an article from the home page with more meanigful text.
+UPDATE celini SET title='Ползата от историята', body='<p><img
+src="http://www.pravoslavieto.com/books/history_paisij/history_Paisij.jpg"
+alt="&quot;История славяноболгарская&quot; св. Паисий Хилендарски" width="300"
+hspace="6" height="483" align="right">Да се познават случилите се по-рано в тоя
+свят неща и делата на ония, които са живеели на земята, е не само полезно, но и
+твърде потребно, любомъдри читателю. Ако навикнеш да прочиташ често тия неща,
+ще се обогатиш с разум, не ще бъдеш много неизкусен и ще отговаряш на малките
+деца и простите хора, когато при случай те запитат за станалите по-рано в света
+деяния от черковната и гражданска история. И не по-малко ще се срамуваш, когато
+не можеш да отговориш за тях.</p>
+
+<p>Отгде ще можеш да добиеш тия знания, ако не от ония, които писаха историята
+на този свят и които при все че не са живели дълго време, защото никому не се
+дарява дълъг живот, за дълго време оставиха писания за тия неща. Сами от себе
+си да се научим не можем, защото кратки са дните на нашия живот на земята.
+Затова с четене на старите летописи и с чуждото умение трябва да попълним
+недостатъчността на нашите години за обогатяване на разума.</p>
+
+<p>Искаш ли да седиш у дома си и да узнаеш без много трудно и опасно пътуване
+миналото на всички царства на тоя свят и ставащите сега събития в тях и да
+употребиш тия знания за умна наслада и полза за себе си и за другите, чети
+историята! Искаш ли да видиш като на театър играта на тоя свят, промяната и
+гибелта на големи царства и царе и непостоянството на тяхното благополучие, как
+господстващите и гордеещите се между народите племена, силни и непобедими в
+битките, славни и почитани от всички, внезапно отслабваха, смиряваха се,
+упадаха, загиваха, изчезваха - чети историята и като познаеш от нея суетата на
+този свят, научи се да го презираш. Историята дава разум не само на всеки
+човек, за да управлява себе си или своя дом, но и на големите владетели за
+добро властвуване: как могат да държат дадените им от бога поданици в страх
+божи, в послушание, тишина, правда и благочестие, как да укротяват и
+изкореняват бунтовниците, как да се опълчват против външните врагове във
+войните, как да ги победят и сключат мир. Виж колко голяма е ползата от
+историята. Накратко това е заявил Василий, источният кесар, на своя син Лъв
+Премъдри. Съветайки го, каза: „Не преставай - рече - да четеш историята на
+древните. Защото там без труд ще намериш онова, за което други много са се
+трудили. От тях ще узнаеш добродетелите на добрите и законопрестъпленията на
+злите, ще познаеш превратностите на човешкия живот и обратите на благополучието
+в него, и непостоянството в този свят, и как и велики държави клонят към
+падение. Ще размислииш и ще видиш наказанието на злите и наградата на добрите.
+От тях се пази!”</p>' WHERE id=6;
+
+-- 201806252200 down
+UPDATE stranici set published=1 WHERE alias='ѿносно';
+-- Synchronise 'published' status of content with their pages
+UPDATE celini SET published=1 where page_id=(SELECT id FROM stranici WHERE alias='ѿносно');
+
